Formula

Enum Formula 

pub enum Formula {
    Atom(Atomic),
    Neg(usize),
    Conj(usize, usize),
    Disj(usize, usize),
    Impl(usize, usize),
    Univ(usize, String, usize),
    Exist(usize, String, usize),
    Comp(usize, String, usize),
}
Represents a recursive logical formula in the Abstract Syntax Tree (AST).

The structure forms a directed acyclic graph when mapped to FormulaArena.

Variants



Atom(Atomic)

An atomic proposition.



Neg(usize)

Logical negation of an inner formula.



Conj(usize, usize)

Logical conjunction (AND) of two formulas.



Disj(usize, usize)

Logical disjunction (OR) of two formulas.



Impl(usize, usize)

Logical implication (=>) between two formulas.



Univ(usize, String, usize)

Universal quantification (∀) over a variable name in an inner formula.



Exist(usize, String, usize)

Existential quantification (∃) over a variable name in an inner formula.



Comp(usize, String, usize)

Set comprehension ({x | P(x)}), defining a new set based on a predicate.